@@ -688,9 +688,29 @@ plot.logistic <- function(x, plots = "coef", conf_lev = .95,
       )
   }
 
+  rem <- c()
+  if (any(grepl("stepwise", x$check))) {
+    if (length(incl) > 0 | length(incl_int) > 0) {
+      if (sum(incl %in% evar) < length(incl)) {
+        rem <- incl[!incl %in% evar]
+      }
+      if (length(incl_int) > 0) {
+        incl_int_split <- strsplit(incl_int, ":") %>%
+          unlist() %>%
+          unique()
+        if (sum(incl_int_split %in% evar) < length(incl_int_split)) {
+          rem <- c(rem, incl_int_split[!incl_int_split %in% evar]) %>% unique()
+        }
+      }
+    }
+  }
+
   if ("pred_plot" %in% plots) {
     ncol <- 2
     if (length(incl) > 0 | length(incl_int) > 0) {
+      if (length(rem) > 0) {
+        return(paste("The following variables are not in the model:", paste(rem, collapse = ", ")))
+      }
       plot_list <- pred_plot(x, plot_list, incl, incl_int, ...)
     } else {
       return("Select one or more variables to generate Prediction plots")
@@ -700,6 +720,9 @@ plot.logistic <- function(x, plots = "coef", conf_lev = .95,
   if ("pdp" %in% plots) {
     nrCol <- 2
     if (length(incl) > 0 | length(incl_int) > 0) {
+      if (length(rem) > 0) {
+        return(paste("The following variables are not in the model:", paste(rem, collapse = ", ")))
+      }
       plot_list <- pdp_plot(x, plot_list, incl, incl_int, ...)
     } else {
       return("Select one or more variables to generate Partial Dependence Plots")
@@ -711,6 +734,7 @@ plot.logistic <- function(x, plots = "coef", conf_lev = .95,
     if (length(evar) < 2) {
       message("Model must contain at least 2 explanatory variables (features). Permutation Importance plot cannot be generated")
     } else {
+      if (any(grepl("stepwise", x$check))) x$evar <- evar
       vi_scores <- varimp(x)
       plot_list[["vip"]] <-
         visualize(vi_scores, yvar = "Importance", xvar = "Variable", type = "bar", custom = TRUE) +
