@@ -151,14 +151,14 @@ test_that("Neural Network - predict with date", {
   expect_equal(res1, res2)
 })
 
-context("Gradient Boosted Trees (gbt)")
-
-test_that("Gradient Boosting - NoLD test", {
-  result <- gbt(titanic, "survived", c("pclass", "sex"), lev = "Yes", early_stopping_rounds = 0)
-  res1 <- round(result$model$importance$Gain, 3)
-  res2 <- c(0.758, 0.210, 0.032)
-  expect_equal(res1, res2, tolerance = 1e-3)
-})
+# context("Gradient Boosted Trees (gbt)")
+#
+# test_that("Gradient Boosting - NoLD test", {
+#   result <- gbt(titanic, "survived", c("pclass", "sex"), lev = "Yes", early_stopping_rounds = 0)
+#   res1 <- round(result$model$importance$Gain, 3)
+#   res2 <- c(0.758, 0.210, 0.032)
+#   expect_equal(res1, res2, tolerance = 1e-3)
+# })
 
 # context("Linear regression (plot.regress)")
 
